@@ -358,3 +358,12 @@ axios.get('/user', {
 });
 
 source.cancel('Operation has been canceled.');
+
+// AxiosError
+
+axios.get('/user')
+  .catch((error) => {
+    if (axios.isAxiosError(error)) {
+      const axiosError: AxiosError = error;
+    }
+  });
